2015-xx-xx v1.0.0
=================
* Added load tests
* Tested accessibility
* Verified documentation and content

2015-xx-xx v0.13.0
==================
* Modified Long Pulling to support Tornado
* Developed advertisement module
* Integrated Karma and Jasmine
* Created JS unitTests
* Installed Grunt
* Increased unitTesting coverage up to 80%
* Added new design for 404 and 500 page

2015-06-29 v0.12.0
==================
* Added message notifier on the page title
* Developed admin panel: table with chat list, action to clear chats manually
* Fixed: clearing closed chats
* Integrated requirejs
* Installed normalize.css
* Added Selenium IDE test cases
* Added technical documentation in RST-format  

2015-03-01 v0.11.0
==================
* Added: unitTests for views
* Added: technical documentation to repository
* Removed: created date from GET:messages response
* Fixed: 404 and 500 error for API
* Fixed: refresh chat page on Firefox shows JS error message
* Modified: design of chat page such as padding, line-height etc.

2014-12-27 v0.10.0
==================
* Modified: moved chat token from parameter to header for API authorization
* Modified: Content Security Policy is turned off for API
* Fixed: CSRF token verification
* Fixed: message date issue in Safari browser
* Fixed: chat was not working in Opera browser
* Fixed: message date is show local time now
* Added: connecting TravisCI with Coveralls
* Added: unitTests for views

2014-12-07 v0.9.0
=================
* Released: working prototype
